''' OUTPUT: "MASS": { "REPORTED": "4 oz/113 g", "SYSTEM INTERNATIONAL": [ "113", "g" ] } ''' ''' GOALS: STEP 1: "MASS": { "REPORTED": "4 oz/113 g", "SYSTEM INTERNATIONAL": [ 113, "g" ] }, STEP 2: "MASS": { "REPORTED": "4 oz/113 g", "SYSTEM INTERNATIONAL": [ 113, "g" ], "SYSTEM INTERNATIONAL E NOTE": [ "113.00E+0", "GRAMS" ], "SYSTEM INTERNATIONAL BASE 10": [ "113.00 * (10 ^ 0)", "GRAMS" ], # # 1.45E-1 POUNDS # "US CUSTOMARY E NOTE POUNDS": [ "0.25", "POUNDS" ] }, '''